@@ -1,6 +1,6 @@
 package Magpie::ConfigReader::XML;
 #ABSTRACT: Magpie Configuration via XML
-$Magpie::ConfigReader::XML::VERSION = '1.141380';
+$Magpie::ConfigReader::XML::VERSION = '1.163200';
 use Moose;
 use XML::LibXML;
 use Magpie::Util;
@@ -97,7 +97,7 @@ sub process_match {
 
     foreach my $child ($node->childNodes) {
         my $name = $child->localname;
-        next unless length $name;
+        next unless $name && length $name;
         if ($name eq 'add') {
             push @input, process_add($child);
         }
@@ -413,15 +413,18 @@ sub random_string {
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Magpie::ConfigReader::XML - Magpie Configuration via XML
 
 =head1 VERSION
 
-version 1.141380
+version 1.163200
 
 =head1 AUTHORS
 
@@ -445,4 +448,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
